@@ -1,10 +1,11 @@
+mod terminal_plotter;
 mod text_plotter;
 
 use std::io::Stdout;
 use std::net::SocketAddr;
-use std::sync::{Arc, Mutex};
 use structopt::StructOpt;
-use text_plotter::{Range, TextPlotter};
+use terminal_plotter::TerminalPlotter;
+use text_plotter::TextPlotter;
 use tokio::net::{TcpListener, TcpStream};
 use tokio_stream::StreamExt;
 use tokio_util::codec::{Framed, LinesCodec};
@@ -28,6 +29,18 @@ struct Opt {
     multiple_connections: bool,
 }
 
+#[derive(Clone)]
+pub struct Range {
+    min: f64,
+    max: f64,
+}
+
+impl Range {
+    pub fn new(min: f64, max: f64) -> Self {
+        Range { min, max }
+    }
+}
+
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
     let opt = Opt::from_args();
@@ -35,14 +48,13 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
     let listener = TcpListener::bind(opt.bind).await?;
 
     let range = Range::new(opt.min, opt.max);
-    let output = std::io::stdout();
 
     let mult_conn = opt.multiple_connections;
 
     if mult_conn {
-        launch_multiple_connections_server(opt, listener, range, output).await
+        launch_multiple_connections_server(opt, listener, range).await
     } else {
-        launch_single_connection_server(opt, listener, range, output).await
+        launch_single_connection_server(opt, listener, range).await
     }
 }
 
@@ -50,18 +62,15 @@ async fn launch_multiple_connections_server(
     opt: Opt,
     listener: TcpListener,
     range: Range,
-    output: std::io::Stdout,
 ) -> Result<(), Box<dyn std::error::Error>> {
-    let tp = TextPlotter::new(opt.bar_capacity, range, output);
-    let tp = Arc::new(Mutex::new(tp));
-
     loop {
         let (socket, _) = listener.accept().await?;
-        let tp = tp.clone();
+        let range = range.clone();
+        let bar_capacity = opt.bar_capacity;
 
         tokio::spawn(async move {
             let server = Framed::new(socket, LinesCodec::new_with_max_length(1024));
-
+            let tp = TerminalPlotter::new(bar_capacity, range);
             process_incoming_data(tp, server).await
         });
     }
@@ -71,26 +80,19 @@ async fn launch_single_connection_server(
     opt: Opt,
     listener: TcpListener,
     range: Range,
-    output: std::io::Stdout,
 ) -> Result<(), Box<dyn std::error::Error>> {
-    let tp = TextPlotter::new(opt.bar_capacity, range, output);
-    let tp = Arc::new(Mutex::new(tp));
-
     loop {
         let (socket, _) = listener.accept().await?;
         let server = Framed::new(socket, LinesCodec::new_with_max_length(1024));
-
-        process_incoming_data(tp.clone(), server).await
+        let tp = TerminalPlotter::new(opt.bar_capacity, range.clone());
+        process_incoming_data(tp, server).await
     }
 }
 
-async fn process_incoming_data(
-    tp: Arc<Mutex<TextPlotter<Stdout>>>,
-    mut server: Framed<TcpStream, LinesCodec>,
-) {
+async fn process_incoming_data(mut tp: TerminalPlotter, mut server: Framed<TcpStream, LinesCodec>) {
     while let Some(Ok(line)) = server.next().await {
         if let Ok(x) = line.parse() {
-            tp.lock().unwrap().update(x);
+            tp.update(x);
         }
     }
 }
